@@ -7,6 +7,16 @@
 #' @importFrom data.table setDT setkey :=
 NULL
 
+# Avoid warning due to ambiguous use of external vector to select df columns:
+# https://github.com/2DegreesInvesting/r2dii.match/pull/317
+all_of_ <- function(x) {
+  if (utils::packageVersion("tidyselect") >= "1.0.0") {
+    tidyselect::all_of(x)
+  } else {
+    identity(x)
+  }
+}
+
 globalVariables(
   c(
     ".",
